@@ -11,13 +11,53 @@
 #' @keywords internal
 #' @export
 expectation <- function(passed, failure_msg, success_msg = "unknown") {
-  error <- is.na(passed)
-  passed <- passed & !error
+  structure(
+    list(
+      passed = passed,
+      error = FALSE,
+      skipped = FALSE,
+      failure_msg = failure_msg,
+      success_msg = success_msg
+    ),
+    class = "expectation"
+  )
+}
+
+expectation_error <- function(error, calls) {
+  msg <- gsub("Error.*?: ", "", as.character(error))
+
+  if (length(calls) > 0) {
+    traceback <- create_traceback(calls)
+    user_calls <- paste0(traceback, collapse = "\n")
+    msg <- paste0(msg, "\n", user_calls)
+  } else {
+    # Need to remove trailing newline from error message to be consistent
+    # with other messages
+    msg <- gsub("\n$", "", msg)
+  }
 
   structure(
     list(
-      passed = passed, error = error,
-      failure_msg = failure_msg, success_msg = success_msg
+      passed = FALSE,
+      error = TRUE,
+      skipped = FALSE,
+      failure_msg = msg,
+      success_msg = "no error occured"
+    ),
+    class = "expectation"
+  )
+}
+
+expectation_skipped <- function(error) {
+  msg <- gsub("Error.*?: ", "", as.character(error))
+
+  structure(
+    list(
+      passed = FALSE,
+      error = FALSE,
+      skipped = TRUE,
+      failure_msg = msg,
+      success_msg = "not skipped"
     ),
     class = "expectation"
   )
