@@ -1,22 +1,7 @@
 #' @include reporter-stop.r
-reporter_accessors <- local({
-  # Default has to be the stop reporter, since it is this that will be run by
-  # default from the command line and in R CMD test.
-  reporter <- StopReporter$new()
+NULL
 
-  set <- function(value) {
-    reporter <<- value
-  }
-  get <- function() {
-    reporter
-  }
-
-  list(get = get, set = set)
-})
-test_reporter <- reporter_accessors$get
-change_reporter_to <- reporter_accessors$set
-
-#' Execute code in specified reporter.
+#' Get/set reporter; execute code in specified reporter.
 #'
 #' Changes global reporter to that specified, runs code and the returns
 #' global reporter back to previous value.
@@ -24,12 +9,36 @@ change_reporter_to <- reporter_accessors$set
 #' @keywords internal
 #' @param reporter test reporter to use
 #' @param code code block to execute
+#' @name reporter-accessors
+NULL
+
+testthat_env <- new.env()
+
+# Default has to be the stop reporter, since it is this that will be run by
+# default from the command line and in R CMD test.
+testthat_env$reporter <- StopReporter$new()
+
+#' @rdname reporter-accessors
+#' @export
+set_reporter <- function(reporter) {
+  old <- testthat_env$reporter
+  testthat_env$reporter <- reporter
+  old
+}
+
+#' @rdname reporter-accessors
+#' @export
+get_reporter <- function() {
+  testthat_env$reporter
+}
+
+#' @rdname reporter-accessors
+#' @export
 with_reporter <- function(reporter, code) {
   reporter <- find_reporter(reporter)
 
-  cur_reporter <- test_reporter()
-  change_reporter_to(reporter)
-  on.exit(change_reporter_to(cur_reporter))
+  old <- set_reporter(reporter)
+  on.exit(set_reporter(old))
 
   reporter$start_reporter()
   force(code)
@@ -48,8 +57,8 @@ find_reporter <- function(reporter) {
   if (inherits(reporter, "Reporter")) return(reporter)
 
   name <- reporter
-  str_sub(name, 1, 1) <- toupper(str_sub(name, 1, 1))
-  name <- str_c(name, "Reporter")
+  substr(name, 1, 1) <- toupper(substr(name, 1, 1))
+  name <- paste0(name, "Reporter")
 
   if (!exists(name)) {
     stop("Can not find test reporter ", reporter, call. = FALSE)
