@@ -1,5 +1,3 @@
-is.error <- function(x) inherits(x, "error")
-
 create_traceback <- function(callstack) {
   if (length(callstack) == 0) return()
   max_lines <- getOption("deparse.max.lines", Inf)
@@ -27,19 +25,3 @@ create_traceback <- function(callstack) {
   calls
 }
 
-try_capture_stack <- function(quoted_code, env) {
-  capture_calls <- function(e) {
-    # Capture call stack, removing last two calls from end (added by
-    # withCallingHandlers), and first frame + 7 calls from start (added by
-    # tryCatch etc)
-    e$calls <- head(sys.calls()[-seq_len(frame + 7)], -2)
-    signalCondition(e)
-  }
-  frame <- sys.nframe()
-
-  tryCatch(
-    withCallingHandlers(eval(quoted_code, env), error = capture_calls),
-    error = identity
-  )
-}
-
